@@ -1,5 +1,6 @@
 package DTL::Fast::Cache::Compressed;
-use strict; use warnings FATAL => 'all'; 
+use strict;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Cache::Serialized';
 
 our %CACHE;
@@ -7,7 +8,7 @@ our %CACHE;
 #@Override
 sub new
 {
-    my( $proto, %kwargs ) = @_;
+    my ( $proto, %kwargs ) = @_;
     require Compress::Zlib;
 
     return $proto->SUPER::new(%kwargs);
@@ -16,9 +17,9 @@ sub new
 #@Override
 sub read_serialized_data
 {
-    my( $self, $key ) = @_;
+    my ( $self, $key ) = @_;
 
-    return 
+    return
         $self->decompress(
             $self->read_compressed_data(
                 $key
@@ -29,33 +30,33 @@ sub read_serialized_data
 #@Override
 sub write_serialized_data
 {
-    my( $self, $key, $data ) = @_;
+    my ( $self, $key, $data ) = @_;
 
     $self->write_compressed_data(
         $key,
         $self->compress(
             $data
         )
-    ) if defined $data; # don't store undef values
+    ) if (defined $data); # don't store undef values
     return $self;
 }
 
 
-sub read_compressed_data{ return shift->SUPER::read_serialized_data(@_) };
+sub read_compressed_data { return shift->SUPER::read_serialized_data(@_) };
 
-sub write_compressed_data{ return shift->SUPER::write_serialized_data(@_) };
+sub write_compressed_data { return shift->SUPER::write_serialized_data(@_) };
 
 sub compress
 {
-    my( $self, $data ) = @_;
-    return if not defined $data;
+    my ( $self, $data ) = @_;
+    return if (not defined $data);
     return Compress::Zlib::memGzip($data);
 }
 
 sub decompress
 {
-    my( $self, $data ) = @_;
-    return if not defined $data;
+    my ( $self, $data ) = @_;
+    return if (not defined $data);
     return Compress::Zlib::memGunzip($data);
 }
 
