@@ -1,43 +1,44 @@
 package DTL::Fast::Cache::File;
-use strict; use warnings FATAL => 'all'; 
+use strict;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Cache::Compressed';
 
 #@Override
 sub new
 {
-    my( $proto, $dir, %kwargs ) = @_;
+    my ( $proto, $dir, %kwargs ) = @_;
 
     die "You should pass a cache directory to the constructor of ".__PACKAGE__
-        if not $dir;
-        
+        if (not $dir);
+
     $dir =~ s{[\/]+$}{}gs;
-    
-    if( 
+
+    if (
         -d $dir
-        and -w $dir
+            and -w $dir
     )
     {
-        $kwargs{'dir'} = $dir;
+        $kwargs{dir} = $dir;
     }
     else
     {
         die "$dir is not a directory or it's not writable for me";
     }
-    
+
     return $proto->SUPER::new(%kwargs);
 }
 
 #@Override
 sub read_compressed_data
 {
-    my( $self, $key ) = @_;
-    my $result; 
-    
-    my $filename = sprintf '%s/%s.dtc', $self->{'dir'}, $key;
-    
-    if( -e $filename )
+    my ( $self, $key ) = @_;
+    my $result;
+
+    my $filename = sprintf '%s/%s.dtc', $self->{dir}, $key;
+
+    if (-e $filename)
     {
-        if( open my $IF, '<', $filename )
+        if (open my $IF, '<', $filename)
         {
             binmode $IF;
             local $/ = undef;
@@ -49,17 +50,17 @@ sub read_compressed_data
             die "Error opening cache file $filename for reading: $!";
         }
     }
-    
-    return $result;    
+
+    return $result;
 }
 
 #@Override
 sub write_compressed_data
 {
-    my( $self, $key, $data ) = @_;
-    my $filename = sprintf '%s/%s.dtc', $self->{'dir'}, $key;
-    
-    if( open my $OF, '>', $filename )
+    my ( $self, $key, $data ) = @_;
+    my $filename = sprintf '%s/%s.dtc', $self->{dir}, $key;
+
+    if (open my $OF, '>', $filename)
     {
         binmode $OF;
         print $OF $data;
