@@ -1,14 +1,15 @@
 package DTL::Fast::Cache::Serialized;
-use strict; use warnings FATAL => 'all'; 
+use strict;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Cache::Runtime';
 use Storable;
 
 #@Override
 sub read_data
 {
-    my( $self, $key ) = @_;
-    
-    return 
+    my ( $self, $key ) = @_;
+
+    return
         $self->deserialize(
             $self->read_serialized_data(
                 $key
@@ -19,48 +20,48 @@ sub read_data
 #@Override
 sub write_data
 {
-    my( $self, $key, $data ) = @_;
-    
+    my ( $self, $key, $data ) = @_;
+
     $self->write_serialized_data(
         $key,
         $self->serialize(
             $data
         )
-    ) if defined $data; # don't store undef values
+    ) if (defined $data); # don't store undef values
     return $self;
 }
 
 sub read_serialized_data
-{ 
-    my( $self, $key ) = @_;
-    return $self->SUPER::read_data($key) 
+{
+    my ( $self, $key ) = @_;
+    return $self->SUPER::read_data($key)
 };
 
 sub write_serialized_data
-{ 
-    my( $self, $key, $data ) = @_;
-    return $self->SUPER::write_data($key, $data) 
+{
+    my ( $self, $key, $data ) = @_;
+    return $self->SUPER::write_data($key, $data)
 };
 
 sub serialize
 {
-    my( $self, $data ) = @_;
-    return if not defined $data;
+    my ( $self, $data ) = @_;
+    return if (not defined $data);
     return Storable::freeze($data);
 }
 
 sub deserialize
 {
-    my( $self, $data ) = @_;
-    return if not defined $data;
+    my ( $self, $data ) = @_;
+    return if (not defined $data);
     my $template = Storable::thaw($data);
-    foreach my $module (keys(%{$template->{'modules'}}))
+    foreach my $module (keys(%{$template->{modules}}))
     {
-        if( not $DTL::Fast::LOADED_MODULES{$module} )
+        if (not $DTL::Fast::LOADED_MODULES{$module})
         {
             require Module::Load;
             Module::Load::load($module);
-            $DTL::Fast::LOADED_MODULES{$module} = time;            
+            $DTL::Fast::LOADED_MODULES{$module} = time;
         }
     }
     return $template;
