@@ -1,5 +1,7 @@
 package DTL::Fast::Expression::Operator::Binary::NotIn;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Expression::Operator::Binary::In';
 
 $DTL::Fast::OPS_HANDLERS{'not in'} = __PACKAGE__;
