@@ -1,14 +1,16 @@
 package DTL::Fast::Expression::Operator::Binary::Or;
-use strict; use utf8; use warnings FATAL => 'all';
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Expression::Operator::Binary::Logical';
 
-$DTL::Fast::OPS_HANDLERS{'or'} = __PACKAGE__;
+$DTL::Fast::OPS_HANDLERS{or} = __PACKAGE__;
 
 sub dispatch
 {
-    my( $self, $arg1, $context) = @_;
+    my ( $self, $arg1, $context) = @_;
 
-    if( UNIVERSAL::can($arg1, 'or') )
+    if (UNIVERSAL::can($arg1, 'or'))
     {
         return $arg1->or($self->get_b($context));
     }
