@@ -1,10 +1,12 @@
 package DTL::Fast::Filter::Capfirst;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
 use locale;
 
-$DTL::Fast::FILTER_HANDLERS{'capfirst'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{capfirst} = __PACKAGE__;
 
 #@Override
 sub filter
