@@ -1,16 +1,18 @@
 package DTL::Fast::Filter::Center;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'center'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{center} = __PACKAGE__;
 
 #@Override
 sub parse_parameters
 {
     my $self = shift;
     die $self->get_parse_error("no width specified for adjusting")
-        if not scalar @{$self->{'parameter'}};
-    $self->{'width'} = $self->{'parameter'}->[0];
+        if (not scalar @{$self->{parameter}});
+    $self->{width} = $self->{parameter}->[0];
     return $self;
 }
 
@@ -18,13 +20,13 @@ sub parse_parameters
 sub filter
 {
     my ($self, $filter_manager, $value, $context) = @_;
-    
-    my $width = $self->{'width'}->render($context);
-    
-    if( $width =~ /^\d+$/ )
+
+    my $width = $self->{width}->render($context);
+
+    if ($width =~ /^\d+$/)
     {
         my $adjustment = ($width - length $value);
-        if( $adjustment > 0 )
+        if ($adjustment > 0)
         {
             $value = $self->adjust($value, $adjustment);
         }
@@ -39,7 +41,7 @@ sub filter
 sub adjust
 {
     my ($self, $value, $adjustment) = @_;
-    return (' 'x int($adjustment/2)).$value;
+    return (' 'x int($adjustment / 2)).$value;
 }
 
 1;
\ No newline at end of file
