@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Cut;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'cut'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{cut} = __PACKAGE__;
 
 use DTL::Fast::Variable;
 
@@ -12,8 +14,8 @@ sub parse_parameters
 {
     my $self = shift;
     die $self->get_parse_error("no substitute specified for removing")
-        if not scalar @{$self->{'parameter'}};
-    $self->{'remove'} = $self->{'parameter'}->[0];
+        if (not scalar @{$self->{parameter}});
+    $self->{remove} = $self->{parameter}->[0];
     return $self;
 }
 
@@ -21,10 +23,10 @@ sub parse_parameters
 sub filter
 {
     my ($self, $filter_manager, $value, $context) = @_;
-    
-    my $remove = $self->{'remove'}->render($context);
+
+    my $remove = $self->{remove}->render($context);
     $value =~ s/\Q$remove\E//gs;
-    
+
     return $value;
 }
 
