@@ -1,16 +1,18 @@
 package DTL::Fast::Filter::Default;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'default'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{default} = __PACKAGE__;
 
 #@Override
 sub parse_parameters
 {
     my $self = shift;
     die $self->get_parse_error("no default value specified")
-        if not scalar @{$self->{'parameter'}};
-    $self->{'default'} = $self->{'parameter'}->[0];
+        if (not scalar @{$self->{parameter}});
+    $self->{default} = $self->{parameter}->[0];
     return $self;
 }
 
@@ -18,8 +20,8 @@ sub parse_parameters
 sub filter
 {
     my ($self, $filter_manager, $value, $context) = @_;
-    
-    return $value || $self->{'default'}->render($context);
+
+    return $value || $self->{default}->render($context);
 }
 
 1;
\ No newline at end of file
