@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::DefaultIfNone;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter::Default';
 
-$DTL::Fast::FILTER_HANDLERS{'default_if_none'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{default_if_none} = __PACKAGE__;
 
 #@Override
 sub filter
@@ -11,8 +13,8 @@ sub filter
     shift;  # filter_manager
     my $value = shift;
     my $context = shift;
-    
-    return $value // $self->{'default'}->render($context);
+
+    return $value // $self->{default}->render($context);
 }
 
 1;
\ No newline at end of file
