@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Dictsort;
-use strict; use utf8; use warnings FATAL => 'all';
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'dictsort'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{dictsort} = __PACKAGE__;
 
 use Scalar::Util qw(looks_like_number);
 use locale;
@@ -12,8 +14,8 @@ sub parse_parameters
 {
     my $self = shift;
     die $self->get_parse_error("no sorting key specified")
-        if not scalar @{$self->{'parameter'}};
-    $self->{'key'} = [split /\./, $self->{'parameter'}->[0]->render()]; # do we need to backup strings here ?
+        if (not scalar @{$self->{parameter}});
+    $self->{key} = [ split /\./, $self->{parameter}->[0]->render() ]; # do we need to backup strings here ?
     return $self;
 }
 
@@ -23,16 +25,16 @@ sub filter
     my ($self, $filter_manager, $value, $context) = @_;
 
     die $self->get_render_error("dictsort works only with array of hashes")
-        if ref $value ne 'ARRAY';
+        if (ref $value ne 'ARRAY');
 
-    return [(
+    return [ (
         sort{
             $self->sort_function(
-                $context->traverse($a, $self->{'key'}, $self)
-                , $context->traverse($b, $self->{'key'}, $self)
+                $context->traverse($a, $self->{key}, $self)
+                , $context->traverse($b, $self->{key}, $self)
             )
         } @$value
-    )];
+    ) ];
 }
 
 sub sort_function
@@ -40,11 +42,11 @@ sub sort_function
     my ($self, $val1, $val2) = @_;
     my $result;
 
-    if( looks_like_number($val1) and looks_like_number($val2))
+    if (looks_like_number($val1) and looks_like_number($val2))
     {
         $result = ($val1 <=> $val2);
     }
-    elsif( UNIVERSAL::can($val1, 'compare'))
+    elsif (UNIVERSAL::can($val1, 'compare'))
     {
         $result = $val1->compare($val2);
     }
