@@ -1,21 +1,23 @@
 package DTL::Fast::Filter::Filesizeformat;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'filesizeformat'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{filesizeformat} = __PACKAGE__;
 
 use Scalar::Util qw(looks_like_number);
 
 our @SUFFIX = (
-    ['KB', 1024]
+    [ 'KB', 1024 ]
 );
 
-unshift @SUFFIX, ['MB', $SUFFIX[0]->[1] * 1024];
-unshift @SUFFIX, ['GB', $SUFFIX[0]->[1] * 1024];
-unshift @SUFFIX, ['TB', $SUFFIX[0]->[1] * 1024];
-unshift @SUFFIX, ['PB', $SUFFIX[0]->[1] * 1024];
-unshift @SUFFIX, ['EB', $SUFFIX[0]->[1] * 1024];
-unshift @SUFFIX, ['ZB', $SUFFIX[0]->[1] * 1024];
+unshift @SUFFIX, [ 'MB', $SUFFIX[0]->[1] * 1024 ];
+unshift @SUFFIX, [ 'GB', $SUFFIX[0]->[1] * 1024 ];
+unshift @SUFFIX, [ 'TB', $SUFFIX[0]->[1] * 1024 ];
+unshift @SUFFIX, [ 'PB', $SUFFIX[0]->[1] * 1024 ];
+unshift @SUFFIX, [ 'EB', $SUFFIX[0]->[1] * 1024 ];
+unshift @SUFFIX, [ 'ZB', $SUFFIX[0]->[1] * 1024 ];
 
 #@Override
 sub filter
@@ -25,13 +27,13 @@ sub filter
     my $value = shift;  # value
     shift;  # context
 
-    if( looks_like_number($value) )
+    if (looks_like_number($value))
     {
         my $str_suffix = 'B';
-        
+
         foreach my $suffix (@SUFFIX)
         {
-            if( $value > $suffix->[1] )
+            if ($value > $suffix->[1])
             {
                 $str_suffix = $suffix->[0];
                 $value = sprintf '%.01f', $value / $suffix->[1];
@@ -40,7 +42,7 @@ sub filter
         }
         $value = sprintf '%s %s', $value, $str_suffix;
     }
-    
+
     return $value;
 }
 
