@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Linebreaks;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'linebreaks'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{linebreaks} = __PACKAGE__;
 
 #@Override
 sub filter
@@ -12,12 +14,12 @@ sub filter
     my $value = shift;  # value
     shift;  # context
 
-    $filter_manager->{'safe'} = 1;
+    $filter_manager->{safe} = 1;
     $value =~ s/(^\s+|\s+$)//gs;
     $value =~ s/\n\n+/<\/p>\n<p>/gs;
     $value =~ s/(?<!<\/p>)\n/<br \/>\n/gsi;
-    $value = "<p>$value</p>" if $value;
-    
+    $value = "<p>$value</p>" if ($value);
+
     return $value;
 }
 
