@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Linebreaksbr;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'linebreaksbr'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{linebreaksbr} = __PACKAGE__;
 
 #@Override
 sub filter
@@ -12,9 +14,9 @@ sub filter
     my $value = shift;  # value
     shift;  # context
 
-    $filter_manager->{'safe'} = 1;
+    $filter_manager->{safe} = 1;
     $value =~ s/\n/<br \/>\n/gsi;
-    
+
     return $value;
 }
 
