@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Linenumbers;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'linenumbers'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{linenumbers} = __PACKAGE__;
 
 #@Override
 sub filter
@@ -12,14 +14,14 @@ sub filter
     my $value = shift;  # value
     shift;  # context
 
-    
+
     my $counter = 1;
-    my $nextcounter = sub{
+    my $nextcounter = sub {
         return $counter++.". ";
     };
 
     $value =~ s/^/$nextcounter->()/gme;
-    
+
     return $value;
 }
 
