@@ -1,15 +1,17 @@
 package DTL::Fast::Filter::MakeList;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'make_list'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{make_list} = __PACKAGE__;
 
 #@Override
 sub filter
 {
     shift;  # self
     shift;  # filter_manager
-    return [shift =~ /(.)/g];
+    return [ shift =~ /(.)/g ];
 }
 
 1;
\ No newline at end of file
