@@ -1,16 +1,18 @@
 package DTL::Fast::Filter::Safe;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'safe'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{safe} = __PACKAGE__;
 
 #@Override
 sub filter
 {
     shift;
 
-    shift->{'safe'} = 1;
-    
+    shift->{safe} = 1;
+
     return shift;
 }
 
