@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Slugify;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'slugify'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{slugify} = __PACKAGE__;
 
 #@Override
 #@todo this should translit locales symbols
@@ -11,10 +13,10 @@ sub filter
     shift;  # self
     shift;  # filter manager
     my $value = shift; # value
-    
+
     $value =~ s/[^\w]+/-/gs;
     $value =~ s/(^\-+|\-+$)//gs;
-    
+
     return lc($value);
 }
 
