@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Strftime;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter::Date';
 
-$DTL::Fast::FILTER_HANDLERS{'strftime'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{strftime} = __PACKAGE__;
 
 use DTL::Fast::Utils;
 
@@ -13,9 +15,9 @@ sub filter
     shift;  # filter_manager
     my $value = shift;
     my $context = shift;
-    
-    my $format = $self->{'format'}->render($context);
-    
+
+    my $format = $self->{format}->render($context);
+
     return DTL::Fast::Utils::time2str($format, $value);
 }
 
