@@ -1,8 +1,10 @@
 package DTL::Fast::Filter::Urlencode;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'urlencode'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{urlencode} = __PACKAGE__;
 
 use DTL::Fast::Utils;
 
@@ -13,7 +15,7 @@ sub filter
     shift;  # filter_manager
     my $value = shift;  # value
     shift;    #context
-    
+
     return DTL::Fast::Utils::escape($value);
 }
 
