@@ -1,16 +1,18 @@
 package DTL::Fast::Filter::Wordwrap;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 use parent 'DTL::Fast::Filter';
 
-$DTL::Fast::FILTER_HANDLERS{'wordwrap'} = __PACKAGE__;
+$DTL::Fast::FILTER_HANDLERS{wordwrap} = __PACKAGE__;
 
 #@Override
 sub parse_parameters
 {
     my $self = shift;
     die $self->get_parse_error("no wrapping width specified")
-        if not scalar @{$self->{'parameter'}};
-    $self->{'maxwidth'} = $self->{'parameter'}->[0];
+        if (not scalar @{$self->{parameter}});
+    $self->{maxwidth} = $self->{parameter}->[0];
     return $self;
 }
 
@@ -18,22 +20,22 @@ sub parse_parameters
 #@Override
 sub filter
 {
-    my($self, $filter_manager, $value, $context ) = @_;
+    my ($self, $filter_manager, $value, $context ) = @_;
 
-    my $maxwidth = $self->{'maxwidth'}->render($context);
+    my $maxwidth = $self->{maxwidth}->render($context);
     my @value = split /\s+/s, $value;
     my @result = ();
     my $width = 0;
-    
+
     foreach my $value (@value)
     {
         my $length = length $value;
-        if( $width ==  0 )
+        if ($width == 0)
         {
             push @result, $value;
             $width += $length;
         }
-        elsif( $length + $width + 1 > $maxwidth )
+        elsif ($length + $width + 1 > $maxwidth)
         {
             push @result, "\n", $value;
             $width = $length;
@@ -44,7 +46,7 @@ sub filter
             $width += $length + 1;
         }
     }
-    
+
     return join '', @result;
 }
 
