@@ -1,11 +1,13 @@
 package DTL::Fast::Replacer::Replacement;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict;
+use utf8;
+use warnings FATAL => 'all';
 
 sub new
 {
     my $proto = shift;
     my $expression = shift;
-    
+
     my $blocksep = '';
     my $block_num = 0;
     while( not $blocksep or $expression =~ /$blocksep/ )
@@ -14,11 +16,11 @@ sub new
     }
 
     my $self = bless {
-        'block_counter' => 0
-        , 'block_ph' => $blocksep.'%s_'
-        , 'blocks' => {}
-    }, $proto;
-    
+            block_counter => 0
+            , block_ph    => $blocksep.'%s_'
+            , blocks      => { }
+        }, $proto;
+
     return $self;
 }
 
@@ -26,10 +28,10 @@ sub add_replacement
 {
     my $self = shift;
     my $value = shift;
-    
-    my $key = sprintf $self->{'block_ph'}, $self->{'block_counter'}++;
-    $self->{'blocks'}->{$key} = $value;
-    
+
+    my $key = sprintf $self->{block_ph}, $self->{block_counter}++;
+    $self->{blocks}->{$key} = $value;
+
     return $key;
 }
 
@@ -38,13 +40,13 @@ sub get_replacement
     my $self = shift;
     my $key = shift;
     my $value = undef;
-    
-    if( exists $self->{'blocks'}->{$key} )
+
+    if (exists $self->{blocks}->{$key})
     {
-        $value = $self->{'blocks'}->{$key};
-        delete $self->{'blocks'}->{$key};
+        $value = $self->{blocks}->{$key};
+        delete $self->{blocks}->{$key};
     }
-    
+
     return $value;
 }
 
