@@ -1,24 +1,26 @@
 package DTL::Fast::Tag::Autoescape;
-use strict; use utf8; use warnings FATAL => 'all'; 
-use parent 'DTL::Fast::Tag';  
+use strict;
+use utf8;
+use warnings FATAL => 'all';
+use parent 'DTL::Fast::Tag';
 
-$DTL::Fast::TAG_HANDLERS{'autoescape'} = __PACKAGE__;
+$DTL::Fast::TAG_HANDLERS{autoescape} = __PACKAGE__;
 
 #@Override
-sub get_close_tag{ return 'endautoescape';}
+sub get_close_tag { return 'endautoescape';}
 
 #@Override
 sub parse_parameters
 {
     my $self = shift;
-    
-    if( $self->{'parameter'} eq 'on' )
+
+    if ($self->{parameter} eq 'on')
     {
-        $self->{'safe'} = 0;
+        $self->{safe} = 0;
     }
-    elsif( $self->{'parameter'} eq 'off' )
+    elsif ($self->{parameter} eq 'off')
     {
-        $self->{'safe'} = 1;
+        $self->{safe} = 1;
     }
     else
     {
@@ -33,10 +35,10 @@ sub render
     my $self = shift;
     my $context = shift;
 
-    $context->push_scope()->set('_dtl_safe' => $self->{'safe'}); 
+    $context->push_scope()->set(_dtl_safe => $self->{safe});
     my $result = $self->SUPER::render($context);
     $context->pop_scope();
-    
+
     return $result;
 }
 
